
# Security Policy

## Reporting a Vulnerability

If you believe you have found a security vulnerability in **c108**, please report it privately.

Please do **not** open a public issue for security reports.

* Use the **“Report a vulnerability”** button on the repository’s **Security** tab.  

We will review and respond as soon as possible.



Thank you for helping keep this project secure ❤️

## Supported Versions

Only the latest release on the `main` branch receives security updates.

